import { BasicEvent } from "@skeldjs/events";
import { SetHatMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player has their player hat updated.
 */
export declare class PlayerSetHatEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetHatMessage | undefined;
    /**
     * The hat that the player had before.
     */
    readonly oldHatId: string;
    /**
     * The new hat that the player has.
     */
    readonly newHatId: string;
    static eventName: "player.sethat";
    eventName: "player.sethat";
    private _atleredHatId;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetHatMessage | undefined, 
    /**
     * The hat that the player had before.
     */
    oldHatId: string, 
    /**
     * The new hat that the player has.
     */
    newHatId: string);
    /**
     * The altered hat that the player will have set instead, if changed.
     */
    get alteredHatId(): string;
    /**
     * Revert the player's hat back to their old hat.
     */
    revert(): void;
    /**
     * Change the hat that the player had set.
     * @param hatId The hat to set.
     */
    setHat(hatId: string): void;
}
