import { BasicEvent } from "@skeldjs/events";
import { SetInfectedMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player (i.e. the host of the room) updates the impostor in the
 * room.
 */
export declare class PlayerSetImpostorsEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetInfectedMessage | undefined;
    /**
     * The players that were made impostors.
     */
    readonly impostors: PlayerData<RoomType>[];
    static eventName: "player.setimpostors";
    eventName: "player.setimpostors";
    private _alteredImpostors;
    private _isDirty;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetInfectedMessage | undefined, 
    /**
     * The players that were made impostors.
     */
    impostors: PlayerData<RoomType>[]);
    /**
     * The changed impostors that will be set instead, if changed.
     */
    get alteredImpostors(): PlayerData<RoomType>[];
    /**
     * Whether the {@link PlayerSetImpostorsEvent.alteredImpostors} is different from
     * {@link PlayerSetImpostorsEvent.impostors}.
     */
    get isDirty(): boolean;
    /**
     * Change the impostors that were set.
     * @param impostors The impostors to set.
     */
    setImpostors(impostors: PlayerData<RoomType>[]): void;
}
