import { BasicEvent } from "@skeldjs/events";
import { SetSkinMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player has their player skin updated.
 */
export declare class PlayerSetSkinEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetSkinMessage | undefined;
    /**
     * The skin that the player had before.
     */
    readonly oldSkinId: string;
    /**
     * The new skin that the player has.
     */
    readonly newSkinId: string;
    static eventName: "player.setskin";
    eventName: "player.setskin";
    private _alteredSkinId;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetSkinMessage | undefined, 
    /**
     * The skin that the player had before.
     */
    oldSkinId: string, 
    /**
     * The new skin that the player has.
     */
    newSkinId: string);
    /**
     * The altered skin that the player will have set instead, if changed.
     */
    get alteredSkin(): string;
    /**
     * Revert the player's skin back to their old skin.
     */
    revert(): void;
    /**
     * Change the skin that the player had set.
     * @param skin The skin to set.
     */
    setSkin(skin: string): void;
}
