"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AirshipStatus = exports.ElectricalDoorsAirship = void 0;
const util_1 = require("@skeldjs/util");
const constant_1 = require("@skeldjs/constant");
const InnerShipStatus_1 = require("./InnerShipStatus");
const systems_1 = require("../systems");
const Door_1 = require("../misc/Door");
const AutoOpenDoor_1 = require("../misc/AutoOpenDoor");
var ElectricalDoorsAirship;
(function (ElectricalDoorsAirship) {
    ElectricalDoorsAirship[ElectricalDoorsAirship["BottomRightNorth"] = 0] = "BottomRightNorth";
    ElectricalDoorsAirship[ElectricalDoorsAirship["CenterSouth"] = 1] = "CenterSouth";
    ElectricalDoorsAirship[ElectricalDoorsAirship["TopRightSouth"] = 2] = "TopRightSouth";
    ElectricalDoorsAirship[ElectricalDoorsAirship["TopCenterSouth"] = 3] = "TopCenterSouth";
    ElectricalDoorsAirship[ElectricalDoorsAirship["TopLeftSouth"] = 4] = "TopLeftSouth";
    ElectricalDoorsAirship[ElectricalDoorsAirship["CenterLeftEast"] = 5] = "CenterLeftEast";
    ElectricalDoorsAirship[ElectricalDoorsAirship["CenterRightWest"] = 6] = "CenterRightWest";
    ElectricalDoorsAirship[ElectricalDoorsAirship["TopRightWest"] = 7] = "TopRightWest";
    ElectricalDoorsAirship[ElectricalDoorsAirship["TopLeftEast"] = 8] = "TopLeftEast";
    ElectricalDoorsAirship[ElectricalDoorsAirship["BottomRightWest"] = 9] = "BottomRightWest";
    ElectricalDoorsAirship[ElectricalDoorsAirship["TopLeftWest"] = 10] = "TopLeftWest";
    ElectricalDoorsAirship[ElectricalDoorsAirship["CenterLeftWest"] = 11] = "CenterLeftWest";
})(ElectricalDoorsAirship = exports.ElectricalDoorsAirship || (exports.ElectricalDoorsAirship = {}));
/**
 * Represents a room object for the Airship map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class AirshipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netId, ownerId, flags, data) {
        super(room, spawnType, netId, ownerId, flags, data);
        this.initialSpawnCenter = new util_1.Vector2(50, 50);
        this.meetingSpawnCenter = new util_1.Vector2(50, 50);
    }
    getComponent(component) {
        if (this.spawnType === constant_1.SpawnType.Airship && component === AirshipStatus) {
            return this.components[0];
        }
        return super.getComponent(component);
    }
    Setup() {
        this.systems.set(constant_1.SystemType.Electrical, new systems_1.SwitchSystem(this, constant_1.SystemType.Electrical, {
            expected: [false, false, false, false, false],
            actual: [false, false, false, false, false],
            brightness: 255,
        }));
        this.systems.set(constant_1.SystemType.MedBay, new systems_1.MedScanSystem(this, constant_1.SystemType.MedBay, {
            queue: []
        }));
        this.systems.set(constant_1.SystemType.Doors, new systems_1.DoorsSystem(this, constant_1.SystemType.Doors, {
            doors: [],
            cooldowns: new Map
        }));
        this.systems.set(constant_1.SystemType.Communications, new systems_1.HudOverrideSystem(this, constant_1.SystemType.Communications, {
            sabotaged: false,
        }));
        this.systems.set(constant_1.SystemType.GapRoom, new systems_1.MovingPlatformSystem(this, constant_1.SystemType.GapRoom, {
            target: undefined,
            side: systems_1.MovingPlatformSide.Left,
            useId: 0,
        }));
        this.systems.set(constant_1.SystemType.Reactor, new systems_1.HeliSabotageSystem(this, constant_1.SystemType.Reactor, {
            countdown: 10000,
            resetTimer: 10000,
            activeConsoles: new Map,
            completedConsoles: new Set([0, 1])
        }));
        this.systems.set(constant_1.SystemType.Decontamination, new systems_1.ElectricalDoorsSystem(this, constant_1.SystemType.Decontamination, {
            doors: [],
        }));
        this.systems.set(constant_1.SystemType.Decontamination2, new systems_1.AutoDoorsSystem(this, constant_1.SystemType.Decontamination2, {
            dirtyBit: 0,
            doors: [],
        }));
        this.systems.set(constant_1.SystemType.Sabotage, new systems_1.SabotageSystem(this, constant_1.SystemType.Sabotage, {
            cooldown: 0,
        }));
        this.systems.set(constant_1.SystemType.Security, new systems_1.SecurityCameraSystem(this, constant_1.SystemType.Security, {
            players: new Set,
        }));
        const electricaldoors = this.systems.get(constant_1.SystemType.Decontamination);
        electricaldoors.doors = [
            new Door_1.Door(electricaldoors, 0, false),
            new Door_1.Door(electricaldoors, 1, false),
            new Door_1.Door(electricaldoors, 2, false),
            new Door_1.Door(electricaldoors, 3, false),
            new Door_1.Door(electricaldoors, 4, false),
            new Door_1.Door(electricaldoors, 5, false),
            new Door_1.Door(electricaldoors, 6, false),
            new Door_1.Door(electricaldoors, 7, false),
            new Door_1.Door(electricaldoors, 8, false),
            new Door_1.Door(electricaldoors, 9, false),
            new Door_1.Door(electricaldoors, 10, false),
            new Door_1.Door(electricaldoors, 11, false)
        ];
        const autodoors = this.systems.get(constant_1.SystemType.Decontamination2);
        autodoors.doors = [
            new AutoOpenDoor_1.AutoOpenDoor(autodoors, 15, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoors, 16, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoors, 17, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoors, 18, true)
        ];
        const doorsystem = this.systems.get(constant_1.SystemType.Doors);
        doorsystem.doors = [
            new Door_1.Door(doorsystem, 0, true),
            new Door_1.Door(doorsystem, 1, true),
            new Door_1.Door(doorsystem, 2, true),
            new Door_1.Door(doorsystem, 3, true),
            new Door_1.Door(doorsystem, 4, true),
            new Door_1.Door(doorsystem, 5, true),
            new Door_1.Door(doorsystem, 6, true),
            new Door_1.Door(doorsystem, 7, true),
            new Door_1.Door(doorsystem, 8, true),
            new Door_1.Door(doorsystem, 9, true),
            new Door_1.Door(doorsystem, 10, true),
            new Door_1.Door(doorsystem, 11, true),
            new Door_1.Door(doorsystem, 12, true),
            new Door_1.Door(doorsystem, 13, true),
            new Door_1.Door(doorsystem, 14, true),
            new Door_1.Door(doorsystem, 15, true),
            new Door_1.Door(doorsystem, 16, true),
            new Door_1.Door(doorsystem, 17, true),
            new Door_1.Door(doorsystem, 18, true),
            new Door_1.Door(doorsystem, 19, true),
            new Door_1.Door(doorsystem, 20, true)
        ];
        const hashSet = new Set;
        let room = AirshipStatus.electricalRooms[0];
        let count = 0;
        while (hashSet.size < AirshipStatus.electricalRooms.length && count++ < 10000) {
            const door = electricaldoors.doors[room[Math.floor(Math.random() * room.length)]];
            const doorSet = AirshipStatus.electricalRooms.find(r => r !== room && r.includes(door.doorId));
            if (!doorSet)
                continue;
            if (hashSet.size !== hashSet.add(doorSet).size) {
                door.setOpen(true);
            }
            if (Math.random() >= 0.5) {
                hashSet.add(room);
                room = doorSet;
            }
        }
        const exitFlag = Math.random() >= 0.5;
        electricaldoors.doors[ElectricalDoorsAirship.TopLeftWest].setOpen(exitFlag);
        electricaldoors.doors[ElectricalDoorsAirship.CenterLeftWest].setOpen(!exitFlag);
    }
    async HandleRpc(rpc) {
        var _a;
        if (rpc.messageTag === constant_1.RpcMessageTag.RepairSystem) {
            if (rpc.systemId === constant_1.SystemType.Doors) {
                const player = this.room.getPlayerByNetId(rpc.netId);
                const doorId = rpc.amount & 0x1f;
                if (doorId >= 15 && doorId <= 18) { // toilet doors go to auto doors system
                    if (player) {
                        (_a = this.systems.get(constant_1.SystemType.Decontamination2)) === null || _a === void 0 ? void 0 : _a.HandleRepair(player, rpc.amount, rpc);
                    }
                    return;
                }
            }
        }
        await super.HandleRpc(rpc);
    }
    getDoorsInRoom(room) {
        return AirshipStatus.roomDoors[room] || [];
    }
}
exports.AirshipStatus = AirshipStatus;
AirshipStatus.roomDoors = {
    [constant_1.SystemType.Communications]: [0, 1, 2, 3],
    [constant_1.SystemType.Brig]: [4, 5, 6],
    [constant_1.SystemType.Kitchen]: [7, 8, 9],
    [constant_1.SystemType.MainHall]: [10, 11],
    [constant_1.SystemType.Records]: [12, 13, 14],
    [constant_1.SystemType.Lounge]: [15, 16, 17, 18],
    [constant_1.SystemType.Medical]: [19, 20]
};
AirshipStatus.electricalRooms = [
    [
        ElectricalDoorsAirship.TopLeftEast,
        ElectricalDoorsAirship.TopLeftSouth
    ],
    [
        ElectricalDoorsAirship.TopLeftEast,
        ElectricalDoorsAirship.TopCenterSouth,
        ElectricalDoorsAirship.TopRightWest
    ],
    [
        ElectricalDoorsAirship.TopRightSouth,
        ElectricalDoorsAirship.TopRightWest
    ],
    [
        ElectricalDoorsAirship.TopRightSouth,
        ElectricalDoorsAirship.CenterRightWest,
        ElectricalDoorsAirship.BottomRightNorth
    ],
    [
        ElectricalDoorsAirship.TopCenterSouth,
        ElectricalDoorsAirship.CenterRightWest,
        ElectricalDoorsAirship.CenterSouth,
        ElectricalDoorsAirship.CenterLeftEast
    ],
    [
        ElectricalDoorsAirship.BottomRightNorth,
        ElectricalDoorsAirship.BottomRightWest
    ],
    [
        ElectricalDoorsAirship.TopLeftSouth,
        ElectricalDoorsAirship.CenterLeftEast,
        ElectricalDoorsAirship.CenterSouth,
        ElectricalDoorsAirship.BottomRightWest
    ]
];
//# sourceMappingURL=AirshipStatus.js.map